<?php

namespace Shirtworks\Qute\Policies;

use Litepie\User\Contracts\UserPolicy;
use Shirtworks\Qute\Models\Qutes;

class QutesPolicy
{

    /**
     * Determine if the given user can view the qutes.
     *
     * @param UserPolicy $user
     * @param Qutes $qutes
     *
     * @return bool
     */
    public function view(UserPolicy $user, Qutes $qutes)
    {
        if ($user->canDo('qute.qutes.view') && $user->isAdmin()) {
            return true;
        }

        return $qutes->user_id == user_id() && $qutes->user_type == user_type();
    }

    /**
     * Determine if the given user can create a qutes.
     *
     * @param UserPolicy $user
     * @param Qutes $qutes
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('qute.qutes.create');
    }

    /**
     * Determine if the given user can update the given qutes.
     *
     * @param UserPolicy $user
     * @param Qutes $qutes
     *
     * @return bool
     */
    public function update(UserPolicy $user, Qutes $qutes)
    {
        if ($user->canDo('qute.qutes.edit') && $user->isAdmin()) {
            return true;
        }

        return $qutes->user_id == user_id() && $qutes->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given qutes.
     *
     * @param UserPolicy $user
     * @param Qutes $qutes
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Qutes $qutes)
    {
        return $qutes->user_id == user_id() && $qutes->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given qutes.
     *
     * @param UserPolicy $user
     * @param Qutes $qutes
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Qutes $qutes)
    {
        if ($user->canDo('qute.qutes.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given qutes.
     *
     * @param UserPolicy $user
     * @param Qutes $qutes
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Qutes $qutes)
    {
        if ($user->canDo('qute.qutes.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
