<?php

namespace Shirtworks\Qute\Workflow;

use Shirtworks\Qute\Models\Qutes;
use Validator;

class QutesValidator
{

    /**
     * Determine if the given qutes is valid for complete status.
     *
     * @param Qutes $qutes
     *
     * @return bool / Validator
     */
    public function complete(Qutes $qutes)
    {
        return Validator::make($qutes->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given qutes is valid for verify status.
     *
     * @param Qutes $qutes
     *
     * @return bool / Validator
     */
    public function verify(Qutes $qutes)
    {
        return Validator::make($qutes->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given qutes is valid for approve status.
     *
     * @param Qutes $qutes
     *
     * @return bool / Validator
     */
    public function approve(Qutes $qutes)
    {
        return Validator::make($qutes->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given qutes is valid for publish status.
     *
     * @param Qutes $qutes
     *
     * @return bool / Validator
     */
    public function publish(Qutes $qutes)
    {
        return Validator::make($qutes->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given qutes is valid for archive status.
     *
     * @param Qutes $qutes
     *
     * @return bool / Validator
     */
    public function archive(Qutes $qutes)
    {
        return Validator::make($qutes->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given qutes is valid for unpublish status.
     *
     * @param Qutes $qutes
     *
     * @return bool / Validator
     */
    public function unpublish(Qutes $qutes)
    {
        return Validator::make($qutes->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
